#! /bin/bash

## 
## Usage: @PROG@ [OPTIONS] [FORTUNE OPTIONS]
## 
##   Uses "fortune" to generate quote files suitable for sgrotum.
## 
## Options:
##   -h, --help      Show this usage message
##   -M, --max NUM   Maximum number of quotes to generate (default is 50)
## 
## Examples:
##   @PROG@ > quotefile-misc
##   @PROG@ riddles > quotefile-riddles
##   @PROG@ 80% linux 10% science 10% startrek > quotefiles-geeky
##   @PROG@ --max 200 -n 72 > quotefile-short
## 
# Han Boetes <han@boetes.org>
# Tim Musson <trmusson@ihug.co.nz>


PROG=$(basename $0)
FORTUNE=/usr/games/fortune
TMPFILE=/tmp/genquotes.$$
nquotes=50


if [ "$1" = "-h" -o "$1" = "--help" ]; then
  sed -n '/^##/s/^## //p' $0 | sed -e "s/@PROG@/${PROG}/g"
  exit 0
elif [ "$1" = "-M" -o "$1" = "--max" ]; then
  shift
  nquotes=$1
  [ "$nquotes" -gt 1 ] || exit 0
  shift
fi

if [ ! -x "$FORTUNE" ]; then
  echo "$PROG: missing '$FORTUNE'" >&2
  exit 1
fi

trap 'rm -f "$TMPFILE"' EXIT

while [ "$nquotes" -gt 0 ]; do
  $FORTUNE -s $@ | tr '\n' ' ' >> "$TMPFILE"
  echo >> "$TMPFILE"
  (( nquotes-- ))
done

# remove control characters, excess space and duplicate lines
cat "$TMPFILE" | tr -d '[\000-\011\013-\031]' |
  sed -e 's/[[:space:]]\+/ /g;s/^ //;s/ $//;s/_\+/_/g' | sort | uniq -u

